@@ -12,6 +12,7 @@
 
 const Lang = imports.lang;
 const GLib = imports.gi.GLib;
+imports.gi.versions.Gst = '1.0';
 const Gst = imports.gi.Gst;
 
 const Gettext = imports.gettext.domain(
@@ -66,7 +67,7 @@ var HelperWebcam = new Lang.Class({
                 this.dmBus.add_watch(GLib.PRIORITY_DEFAULT, this._getMsg);
                 let caps = Gst.Caps.new_empty_simple('video/x-raw');
                 this.deviceMonitor.add_filter('Video/Source', caps);
-
+                this.startMonitor();
                 //update device and caps
                 this.refreshAllInputVideo();
             } else {
@@ -112,7 +113,6 @@ var HelperWebcam = new Lang.Class({
         Lib.TalkativeLog('-@-refresh all video input');
 
         ListDevices = this.getDevicesIV();
-
         //compose devices array
         ListCaps = [];
         for (var index in ListDevices) {
